@@ -29,11 +29,14 @@ enum ADIOS_ERRCODES {
     ,err_invalid_read_method
     ,err_connection_failed
     ,err_out_of_bound
+    ,err_operation_not_supported
+    ,err_end_of_file    // stream: fopen() returns if reached end of stream
+    ,err_too_many_files  // DART allows for using only a fixed number of different filenames
     ,err_unspecified
 };
 
-void error (enum ADIOS_ERRCODES errno, char *fmt, ...);
-void error_at_line (enum ADIOS_ERRCODES errno, const char* filename, unsigned int linenum, char *fmt, ...);
+void adios_error (enum ADIOS_ERRCODES errno, char *fmt, ...);
+void adios_error_at_line (enum ADIOS_ERRCODES errno, const char* filename, unsigned int linenum, char *fmt, ...);
 
 const char* adios_get_last_errmsg (void);
 
