@@ -140,6 +140,7 @@ struct adios_group_struct
     char * group_by;
     char * time_index_name;
     uint32_t time_index;
+    enum ADIOS_FLAG stats_on;
     uint32_t process_id;
 
     struct adios_method_list_struct * methods;
@@ -157,7 +158,7 @@ struct adios_group_list_struct
 struct adios_file_struct
 {
     char * name;
-    char * subfile_name;
+    uint32_t subfile_index; // needs to be set in ADIOS method if generates subfiles
     struct adios_group_struct * group;
     enum ADIOS_METHOD_MODE mode;
     uint64_t data_size;
@@ -410,6 +411,7 @@ int adios_common_declare_group (int64_t * id, const char * name
                                ,const char * coordination_comm
                                ,const char * coordination_var
                                ,const char * time_index
+                               ,enum ADIOS_FLAG stats
                                );
 
 int adios_common_define_var (int64_t group_id, const char * name
@@ -516,6 +518,7 @@ int adios_int_is_num (char * temp); // 1 == yes, 0 == no
 extern "C" {
 #endif
 
+#if 1
 /* LIST */
 typedef struct ListElmt_
 {
@@ -554,6 +557,8 @@ int queue_dequeue (Queue * queue, void ** data);
 #define queue_peek(queue) ((queue)->head == NULL ? NULL : (queue)->head->data)
 #define queue_size list_size
 
+#endif /* 0 */
+
 #ifdef __cplusplus
 }
 #endif
