@@ -28,10 +28,17 @@
 #include "adios_internals_mxml.h"
 #include "buffer.h"
 
+#ifdef DMALLOC
+#include "dmalloc.h"
+#endif
+
 static enum ADIOS_FLAG adios_host_language_fortran = adios_flag_yes;
 
-static struct adios_method_list_struct * adios_methods = 0;
-static struct adios_group_list_struct * adios_groups = 0;
+struct adios_method_list_struct * adios_methods = 0;
+struct adios_group_list_struct * adios_groups = 0;
+
+//extern struct adios_method_list_struct * adios_methods;
+//extern struct adios_group_list_struct * adios_groups;
 
 struct adios_transport_struct * adios_transports = 0;
 static int adios_transports_initialized = 0;
@@ -1955,10 +1962,11 @@ static int parseGroup (mxml_node_t * node)
     const char * coordination_var = 0;
     const char * host_language = 0;
     const char * time_index_name = 0;
+    const char * stats = 0;
 
     int64_t      ptr_new_group;
     struct adios_group_struct * new_group;
-    enum ADIOS_FLAG host_language_fortran = adios_flag_yes;
+    enum ADIOS_FLAG host_language_fortran = adios_flag_yes, enable_stats = adios_flag_yes;
     int i;
 
     for (i = 0; i < node->value.element.num_attrs; i++)
@@ -1975,6 +1983,7 @@ static int parseGroup (mxml_node_t * node)
         GET_ATTR("coordination-var",attr,coordination_var,"adios-group")
         GET_ATTR("host-language",attr,host_language,"adios-group")
         GET_ATTR("time-index",attr,time_index_name,"adios-group")
+        GET_ATTR("stats",attr,stats,"adios-group")
         fprintf (stderr, "config.xml: unknown attribute '%s' on %s "
                          "(ignored)\n"
                 ,attr->name
@@ -2016,6 +2025,29 @@ static int parseGroup (mxml_node_t * node)
         }
     }
 
+    if (!stats)
+    {
+        enable_stats = adios_flag_yes;
+    }
+    else
+    {
+        if (!strcasecmp (stats, "On"))
+        {
+            enable_stats = adios_flag_yes;
+        }
+        else if (!strcasecmp (stats, "Off"))
+        {
+            enable_stats = adios_flag_no;
+        }
+        else
+        {
+            fprintf (stderr, "config.xml, invalid stats %s"
+                    ,stats
+                    );
+            return 0;
+        }
+    }
+
 // fix the bgp bugs 
 /*
     adios_common_declare_group ((int64_t *) &new_group, datagroup_name
@@ -2026,6 +2058,7 @@ static int parseGroup (mxml_node_t * node)
     adios_common_declare_group (&ptr_new_group, datagroup_name
                                ,host_language_fortran, coordination_comm
                                ,coordination_var, time_index_name
+                               ,enable_stats
                                );
      new_group = (struct adios_group_struct *)ptr_new_group;
 
@@ -2701,7 +2734,12 @@ static int parseBuffer (mxml_node_t * node)
 
         if (adios_buffer_alloc_when_get() == ADIOS_BUFFER_ALLOC_NOW)
         {
+
+// Do not attempt to allocate the buffer when this is being called from adios_lint
+#ifndef _INTERNAL
             return adios_set_buffer_size ();
+#endif
+
         }
     }
 
@@ -3256,6 +3294,7 @@ void adios_cleanup ()
 						}
 						j ++;
 					}
+					free (adios_groups->group->vars->stats[c]);
 				}
 
                 free (adios_groups->group->vars->stats);
