@@ -19,7 +19,6 @@
 #include <sys/ioctl.h>
 #include <assert.h>
 
-// mpi
 #include "mpi.h"
 
 // xml parser
@@ -30,6 +29,9 @@
 #include "adios_bp_v1.h"
 #include "adios_internals.h"
 #include "buffer.h"
+#ifdef DMALLOC
+#include "dmalloc.h"
+#endif
 
 static int adios_mpi_initialized = 0;
 
@@ -525,7 +527,7 @@ adios_mpi_build_file_offset(struct adios_MPI_data_struct *md,
                                     + last_offset;
 #endif
             MPI_Scatter (offsets, 1, MPI_LONG_LONG
-                        ,offsets, 1, MPI_LONG_LONG
+                        ,MPI_IN_PLACE, 1, MPI_LONG_LONG
                         ,0, md->group_comm
                         );
             fd->base_offset = offsets [0];
@@ -538,11 +540,11 @@ adios_mpi_build_file_offset(struct adios_MPI_data_struct *md,
             offset[0] = fd->write_size_bytes;
 
             MPI_Gather (offset, 1, MPI_LONG_LONG
-                       ,offset, 1, MPI_LONG_LONG
+                       ,0, 0, 0
                        ,0, md->group_comm
                        );
 
-            MPI_Scatter (offset, 1, MPI_LONG_LONG
+            MPI_Scatter (0, 0, 0
                         ,offset, 1, MPI_LONG_LONG
                         ,0, md->group_comm
                         );
@@ -756,7 +758,7 @@ enum ADIOS_FLAG adios_mpi_should_buffer (struct adios_file_struct * fd
                                   ,fd->group->name, md->old_pg_root
                                   );
                     MPI_Scatter (offsets, 3, MPI_LONG_LONG
-                                ,offsets, 3, MPI_LONG_LONG
+                                ,MPI_IN_PLACE, 3, MPI_LONG_LONG
                                 ,0, md->group_comm
                                 );
                     md->b.read_pg_offset = offsets [0];
@@ -768,7 +770,7 @@ enum ADIOS_FLAG adios_mpi_should_buffer (struct adios_file_struct * fd
                     MPI_Offset offset [3];
                     offset [0] = offset [1] = offset [2] = 0;
 
-                    MPI_Scatter (offset, 3, MPI_LONG_LONG
+                    MPI_Scatter (0, 0, 0
                                 ,offset, 3, MPI_LONG_LONG
                                 ,0, md->group_comm
                                 );
