@@ -17,10 +17,6 @@
 // see if we have MPI or other tools
 #include "config.h"
 
-// mpi
-#if HAVE_MPI
-#include "mpi.h"
-#endif
 
 // xml parser
 #include <mxml.h>
@@ -259,7 +255,7 @@ int adios_posix_open (struct adios_file_struct * fd
         mdfile_name = 0;
     }
 
-    fd->subfile_name = strdup (subfile_name);
+    fd->subfile_index = p->rank;
 
     struct stat s;
     if (stat (subfile_name, &s) == 0)
@@ -1112,7 +1108,9 @@ void adios_posix_close (struct adios_file_struct * fd
                 }
                 else
                 {
-                    MPI_Gather (&buffer_size, 1, MPI_INT
+					// Added this explicit cast to avoid truncation of low-order bytes on BGP
+					int i_buffer_size = (int) buffer_size;
+                    MPI_Gather (&i_buffer_size, 1, MPI_INT
                                ,0, 0, MPI_INT
                                ,0, p->group_comm
                                );
