@@ -207,6 +207,7 @@ int main( int argc, char *argv[] ) {
                 readattrs = true;
                 break;
             case 'n':
+                errno = 0;
                 tmp = strtol(optarg, (char **)NULL, 0);
                 if (errno) {
                     fprintf(stderr, "Error: could not convert --columns value: %s\n", optarg);
@@ -240,6 +241,7 @@ int main( int argc, char *argv[] ) {
                 break;
                 /*
                    case 't':
+                   errno = 0;
                    tmp = strtol(optarg, (char **)NULL, 0);
                    if (errno) {
                    fprintf(stderr, "Error: could not convert --time value: %s\n", optarg);
@@ -1173,9 +1175,9 @@ int print_data_characteristics(void * min, void * max, double * avg, double * st
 
     switch(adiosvartype) {
         case adios_unsigned_byte:
-            if (min) fprintf(outf,(f ? format : "%10hhu  "), ((unsigned char *) min));
+            if (min) fprintf(outf,(f ? format : "%10hhu  "), * ((unsigned char *) min));
             else fprintf(outf, "      null  ");
-            if (max) fprintf(outf,(f ? format : "%10hhu  "), ((unsigned char *) max));
+            if (max) fprintf(outf,(f ? format : "%10hhu  "), * ((unsigned char *) max));
             else fprintf(outf, "      null  ");
             if (avg) fprintf(outf, "%10.2f  ", * avg);
             else fprintf(outf, "      null  ");
@@ -1183,9 +1185,9 @@ int print_data_characteristics(void * min, void * max, double * avg, double * st
             else fprintf(outf, "      null  ");
             break;
         case adios_byte:
-            if (min) fprintf(outf,(f ? format : "%10hhd  "), ((char *) min));
+            if (min) fprintf(outf,(f ? format : "%10hhd  "), * ((char *) min));
             else fprintf(outf, "      null  ");
-            if (max) fprintf(outf,(f ? format : "%10hhd  "), ((char *) max));
+            if (max) fprintf(outf,(f ? format : "%10hhd  "), * ((char *) max));
             else fprintf(outf, "      null  ");
             if (avg) fprintf(outf, "%10.2f  ", * avg);
             else fprintf(outf, "      null  ");
@@ -1259,7 +1261,6 @@ int print_data_characteristics(void * min, void * max, double * avg, double * st
             break;
 
         case adios_real:
-        case adios_double:
             if (min) fprintf(outf,(f ? format : "%10.2g  "), (* (float *) min));
             else fprintf(outf, "      null  ");
             if (max) fprintf(outf,(f ? format : "%10.2g  "), (* (float *) max));
@@ -1269,6 +1270,16 @@ int print_data_characteristics(void * min, void * max, double * avg, double * st
             if (std_dev) fprintf(outf, "%10.2g  ", * std_dev);
             else fprintf(outf, "      null  ");
             break;
+        case adios_double:
+            if (min) fprintf(outf,(f ? format : "%10.2g  "), (* (double *) min));
+            else fprintf(outf, "      null  ");
+            if (max) fprintf(outf,(f ? format : "%10.2g  "), (* (double *) max));
+            else fprintf(outf, "      null  ");
+            if (avg) fprintf(outf, "%10.2g  ", * avg);
+            else fprintf(outf, "      null  ");
+            if (std_dev) fprintf(outf, "%10.2g  ", * std_dev);
+            else fprintf(outf, "      null  ");
+            break;
 
         case adios_long_double:
             //fprintf(outf,(f ? format : "%g "), ((double *) data)[item]);
